[−][src]Struct scpi::error::Error
A SCPI error
If extended-error feature is enabled, an optional extended
message can be added (Example: -241,"Hardware missing;Extended message").
Implementations
impl Error[src]
pub fn new(code: ErrorCode) -> Self[src]
Create new error with specified error code
pub fn extended(code: ErrorCode, _msg: &'static [u8]) -> Self[src]
Create new error with specified error code with an extended message
pub fn get_code(&self) -> i16[src]
Get numeric error code of error
pub fn get_message(&self) -> &'static [u8][src]
Get message of error
pub fn esr_mask(&self) -> u8[src]
Returns a bitmask for the appropriate bit in the ESR for this event/error.